@@ -1,8 +1,10 @@
-from dataclasses import dataclass
-from enum import IntFlag, IntEnum
 import typing
+from dataclasses import dataclass
+from enum import IntEnum, IntFlag
+
 from .field_types import *
 
+
 class CharacterUnlockFlags(IntFlag):
     Ana        = 1 << 0
     Margaret   = 1 << 1
